@@ -274,6 +274,8 @@ def format_test(msg, keyword):
             keyword += and_keyword(msg, parent, "But", TestSubType.But)
         elif test_subtype == TestSubType.Finally:
             keyword += and_keyword(msg, parent, "Finally", TestSubType.Finally)
+        elif test_subtype == TestSubType.Cleanup:
+            keyword += and_keyword(msg, parent, "Cleanup", TestSubType.Cleanup)
         elif test_subtype == TestSubType.Background:
             keyword += and_keyword(msg, parent, "Background", TestSubType.Background)
         elif test_subtype == TestSubType.Paragraph:
@@ -344,6 +346,8 @@ def format_message(msg, keyword, prefix="", predicate=None):
 
     out = textwrap.indent(out, prefix=(indent * (test_type_parent_by_name[msg["test_id"]].count('/') - 1) + " " * 30 + prefix), predicate=predicate)
     out = out.lstrip(" ")
+    if out.endswith("\n"):
+        out = out[:-1]
 
     return color_other(f"{strftimedelta(msg['message_rtime']):>20}{'':3}{indent * (test_type_parent_by_name[msg['test_id']].count('/') - 1)}{keyword} {color_other(out)}\n")
 
