@@ -15,9 +15,9 @@
 import testflows._core.contrib.schema as config
 from testflows._core.test import Module, Suite, Test, Step, NullStep
 from testflows._core.test import TestStep, TestCase, TestSuite, TestModule, TestBackground, TestOutline
-from testflows._core.test import Context
+from testflows._core.test import Context, SharedContext
 from testflows._core.test import Feature, Background, Scenario, Example, Outline
-from testflows._core.test import Critical, Major, Minor, Check, Given, When, Then, And, But, By, Finally
+from testflows._core.test import Critical, Major, Minor, Check, Given, When, Then, And, But, By, Finally, Cleanup
 from testflows._core.test import TestFeature, TestScenario, TestCheck, loads, ordered, retry, retries
 from testflows._core.has import has
 from testflows._core.flags import Flags
@@ -31,7 +31,7 @@ from testflows._core.objects import Node, Tag, Argument, Attribute, Requirement,
 from testflows._core.objects import Secret
 from testflows._core.baseobject import Table
 from testflows._core.filters import The
-from testflows._core.funcs import load, append_path
+from testflows._core.funcs import load, append_path, cleanup
 from testflows._core.funcs import main, args, private_key
 from testflows._core.funcs import metric, ticket, value, note, debug, trace, text
 from testflows._core.funcs import attribute, requirement, tag
